@@ -12,7 +12,7 @@ from oldaplib.src.xsd.xsd_qname import Xsd_QName
 @unique
 class HasPropertyAttr(AttributeClass):
     # order: (QName, mandatory, immutable, datatype)
-    MIN_COUNT = ('sh:minCount', False, False, Xsd_nonNegativeInteger)
-    MAX_COUNT = ('sh:maxCount', False, False, Xsd_nonNegativeInteger)
+    MIN_COUNT = ('sh:minCount', False, False, Xsd_integer)
+    MAX_COUNT = ('sh:maxCount', False, False, Xsd_integer)
     ORDER = ('sh:order', False, False, Xsd_decimal)
     GROUP = ('sh:group', False, False, Xsd_QName)
