@@ -495,7 +495,7 @@ class ResourceInstance:
             raise OldapErrorNoPermission(message)
 
         timestamp = Xsd_dateTimeStamp()
-        if self.name == "Thing":
+        if self.name in ("Thing", "oldap:Thing"):
             self._values[Xsd_QName('oldap:createdBy', validate=False)] = ObservableSet({self._con.userIri})
             self._values[Xsd_QName('oldap:creationDate', validate=False)] = ObservableSet({timestamp})
             self._values[Xsd_QName('oldap:lastModifiedBy', validate=False)] = ObservableSet({self._con.userIri})
@@ -517,7 +517,7 @@ class ResourceInstance:
         sparql += f'{blank:{indent * indent_inc}}INSERT DATA {{'
         sparql += f'\n{blank:{(indent + 1) * indent_inc}}GRAPH {self._graph}:data {{'
 
-        sparql += f'\n{blank:{(indent + 2) * indent_inc}}{self._iri.toRdf} a {self._graph}:{self.name}'
+        sparql += f'\n{blank:{(indent + 2) * indent_inc}}{self._iri.toRdf} a {self.name}'
 
         for prop_iri, values in self._values.items():
             if self.properties.get(prop_iri) and self.properties[prop_iri].prop.datatype == XsdDatatypes.QName:
@@ -537,6 +537,7 @@ class ResourceInstance:
                 raise OldapErrorAlreadyExists(f'Resource with IRI {self._iri} already exists.')
             self._con.transaction_update(sparql)
         except OldapError as e:
+            print(sparql)
             self._con.transaction_abort()
             raise
         self._con.transaction_commit()
@@ -877,7 +878,7 @@ class ResourceInstance:
                         projectShortName: Xsd_NCName | str,
                         s: str,
                         resClass: Xsd_QName | str | None = None,
-                        count_only: bool = False,
+                        countOnly: bool = False,
                         sortBy: SortBy | None = None,
                         limit: int = 100,
                         offset: int = 0,
@@ -896,8 +897,8 @@ class ResourceInstance:
         :param resClass: An optional entity class (Xsd_QName) used to filter results. If provided as a string,
             it is validated and converted to Xsd_QName.
         :type resClass: Xsd_QName | str | None
-        :param count_only: If True, only the count of matching entities will be returned. Defaults to False.
-        :type count_only: bool
+        :param countOnly: If True, only the count of matching entities will be returned. Defaults to False.
+        :type countOnly: bool
         :param sortBy: Optional sorting criterion for the results, such as creation date, last modification date,
             or property values. Defaults to None.
         :type sortBy: SortBy | None
@@ -949,7 +950,7 @@ class ResourceInstance:
         context = Context(name=con.context_name)
         sparql = context.sparql_context
 
-        if (count_only):
+        if (countOnly):
             sparql += f'{blank:{indent * indent_inc}}SELECT (COUNT(DISTINCT ?s) as ?numResult)'
         else:
             sparql += f'{blank:{indent * indent_inc}}SELECT DISTINCT ?s ?t ?p ?o'
@@ -989,7 +990,7 @@ class ResourceInstance:
             if sortBy == SortBy.PROPVAL:
                 sparql += f'\n{blank:{indent * indent_inc}}ORDER BY ASC(LCASE(STR(?o)))'
 
-        if not count_only:
+        if not countOnly:
             sparql += f'\n{blank:{indent * indent_inc}}LIMIT {limit} OFFSET {offset}'
         sparql += '\n'
 
@@ -1000,7 +1001,7 @@ class ResourceInstance:
             print(sparql)
             raise
         res = QueryProcessor(context, jsonres)
-        if count_only:
+        if countOnly:
             return res[0]['numResult']
         else:
             result = {}
@@ -1073,8 +1074,9 @@ class ResourceInstance:
             sparql += f'{blank:{indent * indent_inc}}SELECT (COUNT(DISTINCT ?s) as ?numResult)'
         else:
             sparql += f'{blank:{indent * indent_inc}}SELECT DISTINCT ?s'
-            for index, item in enumerate(includeProperties):
-                sparql += f' ?o{index}'
+            if includeProperties:
+                for index, item in enumerate(includeProperties):
+                    sparql += f' ?o{index}'
             if sortBy:
                 if sortBy == SortBy.CREATED:
                     sparql += ' ?creationDate'
@@ -1087,8 +1089,9 @@ class ResourceInstance:
                 sparql += f'\n{blank:{(indent + 2) * indent_inc}}?s oldap:creationDate ?creationDate .'
             if sortBy == SortBy.LASTMOD:
                 sparql += f'\n{blank:{(indent + 2) * indent_inc}}?s oldap:lastModificationDate ?lastModificationDate .'
-        for index, prop in enumerate(includeProperties):
-            sparql += f'\n{blank:{(indent + 2) * indent_inc}}?s {prop} ?o{index} .'
+        if includeProperties:
+            for index, prop in enumerate(includeProperties):
+                sparql += f'\n{blank:{(indent + 2) * indent_inc}}?s {prop} ?o{index} .'
         sparql += f'\n{blank:{(indent + 2) * indent_inc}}?s rdf:type {resClass} .'
         sparql += f'\n{blank:{(indent + 2) * indent_inc}}?s oldap:grantsPermission ?permset .'
         sparql += f'\n{blank:{(indent + 1) * indent_inc}}}}'
@@ -1107,8 +1110,9 @@ class ResourceInstance:
                 sparql += f'\n{blank:{indent * indent_inc}}ORDER BY ASC(?lastModificationDate)'
             if sortBy == SortBy.PROPVAL:
                 sparql += f'\n{blank:{indent * indent_inc}}ORDER BY'
-                for index, item in enumerate(includeProperties):
-                    sparql += f'\n{blank:{indent * indent_inc}} ?o{index}'
+                if includeProperties:
+                    for index, item in enumerate(includeProperties):
+                        sparql += f'\n{blank:{indent * indent_inc}} ?o{index}'
 
         if not count_only:
             sparql += f'\n{blank:{indent * indent_inc}}LIMIT {limit} OFFSET {offset}'
@@ -1126,8 +1130,9 @@ class ResourceInstance:
             result = {}
             for r in res:
                 tmp = {}
-                for index, item in enumerate(includeProperties):
-                    tmp[item] = r[f'o{index}']
+                if includeProperties:
+                    for index, item in enumerate(includeProperties):
+                        tmp[item] = r[f'o{index}']
 
                 if sortBy:
                     if sortBy == SortBy.CREATED:
@@ -1168,7 +1173,9 @@ class ResourceInstanceFactory:
     """
     _con: IConnection
     _project: Project
+    _sharedProject: Project
     _datamodel: DataModel
+    _sharedModel: DataModel
 
     def __init__(self,
                  con: IConnection,
@@ -1178,20 +1185,30 @@ class ResourceInstanceFactory:
             self._project = project
         else:
             self._project = Project.read(self._con, project)
+        self._sharedProject = Project.read(self._con, "oldap:SharedProject")
 
-        self._datamodel = DataModel.read(con=self._con, project=self._project, ignore_cache=True)
+        self._datamodel = DataModel.read(con=self._con, project=self._project)
+        self._sharedModel = DataModel.read(con=self._con, project=self._sharedProject)
 
-    def createObjectInstance(self, name: Xsd_NCName | str) -> Type:  ## ToDo: Get name automatically from IRI
-        classiri = Xsd_QName(self._project.projectShortName, name)
+    def createObjectInstance(self, name: Xsd_NCName | Xsd_QName | str) -> Type:  ## ToDo: Get name automatically from IRI
+        if isinstance(name, Xsd_QName):
+            classiri = name
+        else:
+            try:
+                classiri = Xsd_QName(name, validate=True)
+            except (ValueError, OldapErrorValue):
+                if not isinstance(name, Xsd_NCName):
+                    name = Xsd_NCName(name, validate=True)
+                classiri = Xsd_QName(self._project.projectShortName, name)
         resclass = self._datamodel.get(classiri)
-        if not isinstance(name, Xsd_NCName):
-            name = Xsd_NCName(name)
+        if not resclass:
+            resclass = self._sharedModel.get(classiri)
         if resclass is None:
             raise OldapErrorNotFound(f'Given Resource Class "{classiri}" not found.')
         return type(str(name), (ResourceInstance,), {
             '_con': self._con,
             'project': self._project,
-            'name': name,
+            'name': resclass.owl_class_iri,
             'factory': self,
             'properties': resclass.properties,
             'superclass': resclass.superclass})
