@@ -5,6 +5,9 @@ from enum import Enum
 from oldaplib.src.helpers.observable_dict import ObservableDict
 from oldaplib.src.helpers.serializer import serializer
 from oldaplib.src.xsd.iri import Iri
+from oldaplib.src.xsd.xsd_integer import Xsd_integer
+from oldaplib.src.xsd.xsd_ncname import Xsd_NCName
+
 
 class TestObservableDict(unittest.TestCase):
 
@@ -24,6 +27,13 @@ class TestObservableDict(unittest.TestCase):
     def test_json(self):
         obs = ObservableDict({Iri('http://gaga.com/a'): 1, Iri('http://gaga.com/b'): 2, Iri('http://gaga.com/c'): 3, Iri('http://gaga.com/d'): 4})
         jsonstr = json.dumps(obs, default=serializer.encoder_default)
+        obs2 = json.loads(jsonstr, object_hook=serializer.decoder_hook)
+        pass
+        self.assertEqual(obs2, {Iri('http://gaga.com/a'): 1, Iri('http://gaga.com/b'): 2, Iri('http://gaga.com/c'): 3, Iri('http://gaga.com/d'): 4})
+
+    def test_json2(self):
+        obs = ObservableDict()
+        jsonstr = json.dumps(obs, default=serializer.encoder_default)
         print(jsonstr)
         obs2 = json.loads(jsonstr, object_hook=serializer.decoder_hook)
-        self.assertEqual(obs2, {Iri('http://gaga.com/a'): 1, Iri('http://gaga.com/b'): 2, Iri('http://gaga.com/c'): 3, Iri('http://gaga.com/d'): 4})
+        print(obs2)
